import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:http/http.dart' as http;
import 'package:pin_code_fields/pin_code_fields.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

import 'Dialogs.dart';
import 'custom-widget-provider/custom-services.dart';

class VerificationWidget extends StatefulWidget {
  VerificationParam params;

  VerificationWidget({this.params});

  @override
  _VerificationWidgetState createState() => _VerificationWidgetState();
}

class _VerificationWidgetState extends State<VerificationWidget> {
  TextEditingController textEditingController = TextEditingController();
  final GlobalKey<State> _keyLoader = new GlobalKey<State>();
  bool isRespKey = false;
  String respMsg = "";

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(10.0),
      child: Column(
        children: [
          SizedBox(
            height: 10,
          ),
          Image(
            height: (widget.params.imgHeight != null) ? widget.params.imgHeight : 200,
            image: (widget.params.ImageUrl != null)
                ? NetworkImage(widget.params.ImageUrl)
                : Image.asset("assets/otp.png"),
            fit: BoxFit.cover,
          ),
          SizedBox(
            height: 10,
          ),
          Text(
            (widget.params.title != null) ? widget.params.title : "Verification Code",
            style: GoogleFonts.getFont('Roboto',
                fontSize: (widget.params.titlefontSize != null) ? widget.params.titlefontSize : 16,
                color: (widget.params.titlefontColor != null) ? widget.params.titlefontColor : Colors.black,
                fontWeight: (widget.params.titlefontWeight != null)
                    ? widget.params.titlefontWeight
                    : FontWeight.bold),
          ),
          SizedBox(
            height: 10,
          ),
          Text(
            (widget.params.msg != null)
                ? widget.params.msg
                : "We have sent the code verifcation to Your Mobile Number",
            style: GoogleFonts.getFont(
              (widget.params.msgfontFamily != null) ? checkFonts(widget.params.msgfontFamily) : 'Roboto',
              color: (widget.params.msgfontColor != null) ? widget.params.msgfontColor : Colors.black,
              fontSize: (widget.params.msgfontSize != null) ? widget.params.msgfontSize : 16,
            ),
          ),
          SizedBox(
            height: 15,
          ),
          Container(
            margin: EdgeInsets.symmetric(horizontal: 30),
            child: PinCodeTextField(
              appContext: context,
              pastedTextStyle: GoogleFonts.getFont('Roboto',
                color: Colors.green.shade600,
                fontWeight: FontWeight.bold,
              ),
              length: (widget.params.OtpLength != null) ? widget.params.OtpLength : 4,
              obscureText: false,
              blinkWhenObscuring: true,
              animationType: AnimationType.fade,
              pinTheme: PinTheme(
                  shape: PinCodeFieldShape.underline,
                  borderRadius: BorderRadius.circular(5),
                  fieldHeight: 50,
                  fieldWidth: 40,
                  activeFillColor: Colors.white,
                  activeColor: Colors.white,
                  selectedColor: Colors.white,
                  inactiveColor: Colors.white,
                  disabledColor: Colors.white,
                  selectedFillColor: Colors.white,
                  inactiveFillColor: Colors.white,
                  errorBorderColor: Colors.white),
              cursorColor: Colors.black,
              animationDuration: Duration(milliseconds: 300),
              enableActiveFill: true,
              // errorAnimationController: errorController,
              controller: textEditingController,
              keyboardType: TextInputType.number,
              boxShadows: [
                BoxShadow(
                  offset: Offset(0, 1),
                  color: Colors.black12,
                  blurRadius: 10,
                )
              ],
              onCompleted: (v) {},
              // onTap: () {
              //   print("Pressed");
              // },
              onChanged: (value) {
                // print(value);
              },
              beforeTextPaste: (text) {
                return true;
              },
            ),
          ),
          SizedBox(
            height: 15,
          ),
          FlatButton(
            height: widget.params.btnHeight,
            color: (widget.params.btnColor != null) ? widget.params.btnColor : Colors.black,
            // textColor: Colors.white,
            padding: EdgeInsets.only(
              left: (widget.params.btnPaddingLeft != null) ? widget.params.btnPaddingLeft : 15,
              top: (widget.params.btnPaddingTop != null) ? widget.params.btnPaddingTop : 15,
              right: (widget.params.btnPaddingRight != null) ? widget.params.btnPaddingRight : 15,
              bottom: (widget.params.btnPaddingBottom != null) ? widget.params.btnPaddingBottom : 15,
            ),
            shape: RoundedRectangleBorder(
                side: BorderSide(
                    color:
                        (widget.params.btnBorderColor != null) ? widget.params.btnBorderColor : Colors.blue,
                    width: (widget.params.btnBorderWidth != null) ? widget.params.btnBorderWidth : 1,
                    style: BorderStyle.solid),
                borderRadius: BorderRadius.circular(50)),
            child: Text(
              (widget.params.btnText != null) ? widget.params.btnText : "Submit",
              style: GoogleFonts.getFont(
                (widget.params.msgfontFamily != null) ? checkFonts(widget.params.msgfontFamily) : 'Roboto',
                color: (widget.params.btnfontColor != null) ? widget.params.btnfontColor : Colors.black,
                fontSize: (widget.params.btnfontSize != null) ? widget.params.btnfontSize : 16,

              ),
            ),
            onPressed: () async {
              if (textEditingController.text.length == widget.params.OtpLength) {
                // return (widget.onSubmitPress != null)
                //     ? widget.onSubmitPress(textEditingController.text)
                //     : null;
                try {
                  String msg = (widget.params.waitMsg != null) ? widget.params.waitMsg : "Verifying OTP...";
                  Dialogs.showLoadingDialog(
                      context: context,
                      key: _keyLoader,
                      backgroundColor: widget.params.dialogBackgroundColor,
                      progressTextColor: widget.params.dialogIndiactorTextColor,
                      msg: msg);

                  var response = await postRequest(
                      widget.params.postAPI, widget.params.payloadName, textEditingController.text);

                  Navigator.of(_keyLoader.currentContext, rootNavigator: true).pop();

                  var resp = json.decode(response.body);

                  if (widget.params.responseKey != null) {
                    setState(() {
                      isRespKey = true;
                      respMsg = resp["message"].toString();
                      final snackBar = SnackBar(
                        backgroundColor: Colors.lightGreen,
                        content: Text(respMsg),
                      );
                      ScaffoldMessenger.of(context).showSnackBar(snackBar);
                    });
                  } else {
                    setState(() {
                      isRespKey = false;
                    });
                  }

                  if (response.statusCode.toString() == '200') {
                    return (widget.params.onSuccess != null) ? widget.params.onSuccess() : null;
                  } else {
                    return (widget.params.onFailure != null) ? widget.params.onFailure() : null;
                  }
                } catch (e) {}
              } else {
                final snackBar = SnackBar(
                  backgroundColor: Colors.redAccent,
                  content: Text('Invalid OTP.'),
                );
                ScaffoldMessenger.of(context).showSnackBar(snackBar);
              }
            },
          ),
        ],
      ),
    );
  }

  Future postRequest(String url, String key, String val) async {
    Map data = {
      key: val,
    };

    var body = json.encode(data);
    var response =
        await http.post(Uri.parse(url), headers: {"Content-Type": "application/json"}, body: body);
    return response;
  }
}
