
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

import 'custom-widget-provider/custom-services.dart';
class ContactCardWidget extends StatefulWidget {
  final ContactCardParameters  cardParameters;
  ContactCardWidget({Key key, this.cardParameters}) : super(key: key);

  @override
  _ContactCardWidgetState createState() => _ContactCardWidgetState();
}

class _ContactCardWidgetState extends State<ContactCardWidget> {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding:  EdgeInsets.only(
        left:   widget.cardParameters.paddingLeft!=null?widget.cardParameters.paddingLeft:0,
        right:  widget.cardParameters.paddingRight!=null?widget.cardParameters.paddingRight:0,
        top:    widget.cardParameters.paddingTop!=null?widget.cardParameters.paddingTop:0,
        bottom:  widget.cardParameters.paddingBottom!=null?widget.cardParameters.paddingBottom:0,
      ),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          GestureDetector(
            onTap:  (widget.cardParameters.onclick!=null)?widget.cardParameters.onclick:(){},
            child: Card(
                color: widget.cardParameters.backgroundColorOuterCard??Colors.white,
                elevation: widget.cardParameters.elevation!=null?widget.cardParameters.elevation:2,
                shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(widget.cardParameters.borderRadius!=null?widget.cardParameters.borderRadius:10)),
                child:  (widget.cardParameters.imagePosition=="Up")?
                Column(
                  children: [
                    if(widget.cardParameters.urlImage!=null)
                      if(widget.cardParameters.urlImage!='null')
                        Padding(
                          padding:  EdgeInsets.fromLTRB(
                            widget.cardParameters.imagePaddingLeft!=null? widget.cardParameters.imagePaddingLeft:0,
                            widget.cardParameters.imagePaddingTop!=null? widget.cardParameters.imagePaddingTop:0,
                            widget.cardParameters.imagePaddingRight!=null? widget.cardParameters.imagePaddingRight:0,
                            widget.cardParameters.imagePaddingBottom!=null? widget.cardParameters.imagePaddingBottom:0,
                          ),

                          child: (widget.cardParameters.circleAvatar)?
                          CircleAvatar(
                            backgroundImage:
                            NetworkImage(
                                widget.cardParameters.urlImage),
                            radius: widget.cardParameters.circleAvatarRadius!=null?widget.cardParameters.circleAvatarRadius:15,
                          ):
                          Image.network(
                            widget.cardParameters.urlImage,
                            height: widget.cardParameters.imageHeight!=null?widget.cardParameters.imageHeight:100,
                            width:  widget.cardParameters.imageWidth!=null?widget.cardParameters.imageWidth:100,
                          ),
                        ),
                    //details
                    Card(
                      color: widget.cardParameters.backgroundColorInnerCard??Colors.white,
                      elevation: widget.cardParameters.elevationInnerCard!=null?widget.cardParameters.elevationInnerCard:2,
                      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(widget.cardParameters.borderRadius!=null?widget.cardParameters.borderRadius:10)),
                      child: Padding(
                        padding: const EdgeInsets.all(4.0),
                        child: Row(
                          children: [
                            Expanded(
                              flex: 5,
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                mainAxisSize: MainAxisSize.min,
                                children: [
                                  const SizedBox(height: 8),
                                  for(int i =0; i<widget.cardParameters.items.length;i++)
                                    for(var key in widget.cardParameters.items[i].keys)
                                      details(
                                          text: key,
                                          icon: widget.cardParameters.items[i][key],
                                          iconColor: widget.cardParameters.iconColor,
                                          textColor: widget.cardParameters.textColor,
                                          fontSize: widget.cardParameters.fontSize,
                                          iconSize:  widget.cardParameters.iconSize
                                      ),
                                  SizedBox(height: widget.cardParameters.heightbetweenTextDescription!=null?widget.cardParameters.heightbetweenTextDescription:8),
                                  if(widget.cardParameters.descriptionText!=null)
                                    if((widget.cardParameters.descriptionText!='null'))
                                      Padding(
                                        padding:  EdgeInsets.fromLTRB(
                                          widget.cardParameters.descriptionTextPaddingLeft??0,
                                          widget.cardParameters.descriptionTextPaddingTop??0,
                                          widget.cardParameters.descriptionTextPaddingRight??0,
                                          widget.cardParameters.descriptionTextPaddingBottom??0,
                                        ),
                                        child: Row(
                                          mainAxisAlignment: MainAxisAlignment.start,
                                          crossAxisAlignment: CrossAxisAlignment.center,
                                          children: [
                                            Expanded(
                                              //flex:5,
                                              child: Text(widget.cardParameters.descriptionText,style: GoogleFonts.getFont(
                                                (widget.cardParameters.descriptionfontFamily != null)
                                                    ? checkFonts(widget.cardParameters.descriptionfontFamily)
                                                    : 'Roboto',fontSize: widget.cardParameters.descriptionTextFontSize!=null?widget.cardParameters.descriptionTextFontSize:10,
                                                color: widget.cardParameters.descriptionTextColor??Colors.white,
                                              ),),
                                            ),
                                          ],
                                        ),
                                      ),

                                ],
                              ),
                            ),
                            if(widget.cardParameters.expandableIcon && widget.cardParameters.expandableIconSize!=0 )
                              Expanded(
                                  flex:1,
                                  child:
                                  Icon(Icons.navigate_next_rounded,color: widget.cardParameters.expandableIconColor!=null?widget.cardParameters.expandableIconColor:Colors.black,
                                    size: widget.cardParameters.expandableIconSize!=null?widget.cardParameters.expandableIconSize:0,
                                  )
                              )
                          ],
                        ),
                      ),
                    )
                  ],
                ):
                (widget.cardParameters.imagePosition=="Down")?
                Column(
                  children: [
                    Card(
                      color: widget.cardParameters.backgroundColorInnerCard??Colors.white,
                      elevation: widget.cardParameters.elevationInnerCard!=null?widget.cardParameters.elevationInnerCard:2,
                      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(widget.cardParameters.borderRadius!=null?widget.cardParameters.borderRadius:10)),
                      child: Padding(
                        padding: const EdgeInsets.all(4.0),
                        child: Row(
                          children: [
                            Expanded(
                              flex: 5,
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                mainAxisSize: MainAxisSize.min,
                                children: [
                                  const SizedBox(height: 8),
                                  for(int i =0; i<widget.cardParameters.items.length;i++)
                                    for(var key in widget.cardParameters.items[i].keys)
                                      details(
                                          text: key,
                                          icon: widget.cardParameters.items[i][key],
                                          iconColor: widget.cardParameters.iconColor,
                                          textColor: widget.cardParameters.textColor,
                                          fontSize: widget.cardParameters.fontSize,
                                          iconSize:  widget.cardParameters.iconSize
                                      ),
                                  SizedBox(height: widget.cardParameters.heightbetweenTextDescription!=null?widget.cardParameters.heightbetweenTextDescription:8),
                                  if((widget.cardParameters.descriptionText!=null))
                                    if((widget.cardParameters.descriptionText!='null'))
                                      Padding(
                                        padding:  EdgeInsets.fromLTRB(
                                          widget.cardParameters.descriptionTextPaddingLeft??0,
                                          widget.cardParameters.descriptionTextPaddingTop??0,
                                          widget.cardParameters.descriptionTextPaddingRight??0,
                                          widget.cardParameters.descriptionTextPaddingBottom??0,
                                        ),
                                        child: Row(
                                          mainAxisAlignment: MainAxisAlignment.start,
                                          crossAxisAlignment: CrossAxisAlignment.center,
                                          children: [
                                            Expanded(
                                              //flex:5,
                                              child: Text(widget.cardParameters.descriptionText,style: GoogleFonts.getFont(
                                                (widget.cardParameters.descriptionfontFamily != null)
                                                    ?checkFonts(widget.cardParameters.descriptionfontFamily)
                                                    : 'Roboto',
                                                fontSize: widget.cardParameters.descriptionTextFontSize!=null?widget.cardParameters.descriptionTextFontSize:10,
                                                color: widget.cardParameters.descriptionTextColor??Colors.white,
                                              ),),
                                            ),

                                          ],
                                        ),
                                      ),
                                ],
                              ),
                            ),
                            if(widget.cardParameters.expandableIcon && widget.cardParameters.expandableIconSize!=0 )
                              Expanded(
                                  flex:1,
                                  child:
                                  Icon(Icons.navigate_next_rounded,color: widget.cardParameters.expandableIconColor!=null?widget.cardParameters.expandableIconColor:Colors.black,
                                    size: widget.cardParameters.expandableIconSize!=null?widget.cardParameters.expandableIconSize:0,
                                  ))
                          ],
                        ),
                      ),
                    ),
                    if(widget.cardParameters.urlImage!=null)
                      if(widget.cardParameters.urlImage!='null')
                        Padding(
                          padding:  EdgeInsets.fromLTRB(
                            widget.cardParameters.imagePaddingLeft!=null? widget.cardParameters.imagePaddingLeft:0,
                            widget.cardParameters.imagePaddingTop!=null? widget.cardParameters.imagePaddingTop:0,
                            widget.cardParameters.imagePaddingRight!=null? widget.cardParameters.imagePaddingRight:0,
                            widget.cardParameters.imagePaddingBottom!=null? widget.cardParameters.imagePaddingBottom:0,
                          ),
                          child: (widget.cardParameters.circleAvatar)?
                          CircleAvatar(
                            backgroundImage: NetworkImage(
                                widget.cardParameters.urlImage),
                            radius: widget.cardParameters.circleAvatarRadius!=null?widget.cardParameters.circleAvatarRadius:15,
                          ):
                          Image.network(
                            widget.cardParameters.urlImage,
                            height: widget.cardParameters.imageHeight!=null?widget.cardParameters.imageHeight:100,
                            width:  widget.cardParameters.imageWidth!=null?widget.cardParameters.imageWidth:100,
                          ),
                        )
                    //details

                  ],
                ):
                (widget.cardParameters.imagePosition=="Left")?
                Row(
                  children: [
                    if(widget.cardParameters.urlImage!=null)
                      if(widget.cardParameters.urlImage!='null')
                        Expanded(flex: widget.cardParameters.flexImage!=null? widget.cardParameters.flexImage:1,
                            child:
                            Padding(
                              padding:  EdgeInsets.fromLTRB(
                                widget.cardParameters.imagePaddingLeft!=null? widget.cardParameters.imagePaddingLeft:0,
                                widget.cardParameters.imagePaddingTop!=null? widget.cardParameters.imagePaddingTop:0,
                                widget.cardParameters.imagePaddingRight!=null? widget.cardParameters.imagePaddingRight:0,
                                widget.cardParameters.imagePaddingBottom!=null? widget.cardParameters.imagePaddingBottom:0,
                              ),
                              child: (widget.cardParameters.circleAvatar)?
                              CircleAvatar(
                                backgroundImage: NetworkImage(
                                    widget.cardParameters.urlImage),
                                radius: widget.cardParameters.circleAvatarRadius!=null?widget.cardParameters.circleAvatarRadius:15,
                              ):
                              Image.network(
                                widget.cardParameters.urlImage,
                                height: widget.cardParameters.imageHeight!=null?widget.cardParameters.imageHeight:100,
                                width:  widget.cardParameters.imageWidth!=null?widget.cardParameters.imageWidth:100,
                              ),
                            )
                        ),
                    //details
                    Expanded(
                      flex: widget.cardParameters.flexText!=null?widget.cardParameters.flexText:4,
                      child: Card(
                        color: widget.cardParameters.backgroundColorInnerCard??Colors.white,
                        elevation: widget.cardParameters.elevationInnerCard!=null?widget.cardParameters.elevationInnerCard:2,
                        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(widget.cardParameters.borderRadius!=null?widget.cardParameters.borderRadius:10)),
                        child: Padding(
                          padding: const EdgeInsets.all(4.0),
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            mainAxisSize: MainAxisSize.min,
                            children: [
                              const SizedBox(height: 8),
                              for(int i =0; i<widget.cardParameters.items.length;i++)
                                for(var key in widget.cardParameters.items[i].keys)
                                  details(
                                      text: key,
                                      icon: widget.cardParameters.items[i][key],
                                      iconColor: widget.cardParameters.iconColor,
                                      textColor: widget.cardParameters.textColor,
                                      fontSize: widget.cardParameters.fontSize,
                                      iconSize:  widget.cardParameters.iconSize
                                  ),
                              SizedBox(height: widget.cardParameters.heightbetweenTextDescription!=null?widget.cardParameters.heightbetweenTextDescription:8),
                              if(widget.cardParameters.descriptionText!=null)
                                if(widget.cardParameters.descriptionText!='null')
                                  Padding(
                                    padding:  EdgeInsets.fromLTRB(
                                      widget.cardParameters.descriptionTextPaddingLeft??0,
                                      widget.cardParameters.descriptionTextPaddingTop??0,
                                      widget.cardParameters.descriptionTextPaddingRight??0,
                                      widget.cardParameters.descriptionTextPaddingBottom??0,
                                    ),
                                    child: Row(
                                      mainAxisAlignment: MainAxisAlignment.start,
                                      crossAxisAlignment: CrossAxisAlignment.center,
                                      children: [
                                        Expanded(
                                          // flex:5,
                                          child: Text(widget.cardParameters.descriptionText,style: GoogleFonts.getFont(
                                            (widget.cardParameters.descriptionfontFamily != null)
                                                ? checkFonts(widget.cardParameters.descriptionfontFamily)
                                                : 'Roboto',
                                            fontSize: widget.cardParameters.descriptionTextFontSize!=null?widget.cardParameters.descriptionTextFontSize:10,
                                            color: widget.cardParameters.descriptionTextColor??Colors.white,
                                          ),),
                                        ),
                                      ],
                                    ),
                                  ),
                            ],
                          ),
                        ),
                      ),
                    ),
                    if(widget.cardParameters.expandableIcon && widget.cardParameters.expandableIconSize!=0 )
                      Expanded(
                          flex:1,
                          child:  Icon(Icons.navigate_next_rounded,color: widget.cardParameters.expandableIconColor!=null?widget.cardParameters.expandableIconColor:Colors.black,
                            size: widget.cardParameters.expandableIconSize!=null?widget.cardParameters.expandableIconSize:0,
                          ))
                  ],
                ):
                Row(
                  children: [
                    //details
                    Expanded(
                      flex: widget.cardParameters.flexText!=null?widget.cardParameters.flexText:4,
                      child: Card(
                        color: widget.cardParameters.backgroundColorInnerCard??Colors.white,
                        elevation: widget.cardParameters.elevation!=null?widget.cardParameters.elevation:2,
                        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(widget.cardParameters.borderRadius!=null?widget.cardParameters.borderRadius:10)),
                        child: Padding(
                          padding: const EdgeInsets.all(4.0),
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            mainAxisSize: MainAxisSize.min,
                            children: [
                              const SizedBox(height: 8),
                              for(int i =0; i<widget.cardParameters.items.length;i++)
                                for(var key in widget.cardParameters.items[i].keys)
                                  details(
                                      text: key,
                                      icon: widget.cardParameters.items[i][key],
                                      iconColor: widget.cardParameters.iconColor,
                                      textColor: widget.cardParameters.textColor,
                                      fontSize: widget.cardParameters.fontSize,
                                      iconSize:  widget.cardParameters.iconSize
                                  ),
                              SizedBox(height: widget.cardParameters.heightbetweenTextDescription!=null?widget.cardParameters.heightbetweenTextDescription:8),
                              if(widget.cardParameters.descriptionText!=null)
                                if(widget.cardParameters.descriptionText!='null')
                                  Padding(
                                    padding:  EdgeInsets.fromLTRB(
                                      widget.cardParameters.descriptionTextPaddingLeft??0,
                                      widget.cardParameters.descriptionTextPaddingTop??0,
                                      widget.cardParameters.descriptionTextPaddingRight??0,
                                      widget.cardParameters.descriptionTextPaddingBottom??0,
                                    ),
                                    child: Row(
                                      mainAxisAlignment: MainAxisAlignment.start,
                                      crossAxisAlignment: CrossAxisAlignment.center,
                                      children: [
                                        Expanded(
                                          //flex:5,
                                          child: Text(widget.cardParameters.descriptionText,style: GoogleFonts.getFont(
                                            (widget.cardParameters.descriptionfontFamily != null)
                                                ? checkFonts(widget.cardParameters.descriptionfontFamily)
                                                : 'Roboto',
                                            fontSize: widget.cardParameters.descriptionTextFontSize!=null?widget.cardParameters.descriptionTextFontSize:10,
                                            color: widget.cardParameters.descriptionTextColor??Colors.white,
                                          ),),
                                        ),

                                      ],
                                    ),
                                  ),
                            ],
                          ),
                        ),
                      ),
                    ),
                    if(widget.cardParameters.urlImage!=null)
                      if(widget.cardParameters.urlImage!='null')
                        Expanded(flex: widget.cardParameters.flexImage!=null? widget.cardParameters.flexImage:1,
                            child: Padding(
                              padding:  EdgeInsets.fromLTRB(
                                widget.cardParameters.imagePaddingLeft!=null? widget.cardParameters.imagePaddingLeft:0,
                                widget.cardParameters.imagePaddingTop!=null? widget.cardParameters.imagePaddingTop:0,
                                widget.cardParameters.imagePaddingRight!=null? widget.cardParameters.imagePaddingRight:0,
                                widget.cardParameters.imagePaddingBottom!=null? widget.cardParameters.imagePaddingBottom:0,
                              ),
                              child: (widget.cardParameters.circleAvatar)?
                              CircleAvatar(
                                backgroundImage: NetworkImage(
                                    widget.cardParameters.urlImage),
                                radius: widget.cardParameters.circleAvatarRadius!=null?widget.cardParameters.circleAvatarRadius:15,
                              ):
                              Image.network(
                                widget.cardParameters.urlImage,
                                height: widget.cardParameters.imageHeight!=null?widget.cardParameters.imageHeight:100,
                                width:  widget.cardParameters.imageWidth!=null?widget.cardParameters.imageWidth:100,
                              ),
                            )
                        ),
                    if(widget.cardParameters.expandableIcon && widget.cardParameters.expandableIconSize!=0 )
                      Expanded(
                          flex:1,
                          child:  Icon(Icons.navigate_next_rounded,color: widget.cardParameters.expandableIconColor!=null?widget.cardParameters.expandableIconColor:Colors.black,
                            size: widget.cardParameters.expandableIconSize!=null?widget.cardParameters.expandableIconSize:0,
                          ))

                  ],
                )
            ),
          )
        ],
      ),
    );
  }
  Widget details({String text , Color iconColor, Color textColor, IconData icon, double fontSize,double iconSize}){

    //if((icon!=null || (text!='null')))
    return
      Column(
        children: [
          SizedBox(height: widget.cardParameters.heightBetweenText!=null?widget.cardParameters.heightBetweenText:6,),
          Padding(
            padding:  EdgeInsets.fromLTRB(
                widget.cardParameters.textPaddingLeft??0,
                widget.cardParameters.textPaddingTop??0,
                widget.cardParameters.textPaddingRight??0,
                widget.cardParameters.textPaddingBottom??0
            ),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                (icon!=null)?Icon(icon,size:iconSize!=null?iconSize:10 ,color: iconColor??Colors.black,):SizedBox.shrink(),
                (icon!=null)?SizedBox(width: 8,):SizedBox.shrink(),
                if(text!=null)
                  if(text!='null')
                    Expanded(
                        child:
                        Text(text,style: GoogleFonts.getFont( (widget.cardParameters.textfontFamily != null)
                            ? checkFonts(widget.cardParameters.textfontFamily)
                            : 'Roboto',
                            fontSize: fontSize!=null?fontSize:12,color: textColor??Colors.black)
                          ,)),
              ],
            ),
          ),
          SizedBox(height: widget.cardParameters.heightBetweenText!=null?widget.cardParameters.heightBetweenText:6,),
        ],
      );

  }
}
