/*
Description:
Card that can be used to detail out about a transaction, event etc.
The card is customizable in a way that it can hold a heading and heading value.
It can also hold in two description properties and their values alongside an icon for each.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-DetailsCard.dart';

Usage:

//Defining the card object
OpportunityDetailsCardData detailsCardData = new OpportunityDetailsCardData(
        height: 250,
        backgroundColor: Colors.red,
        amountTextColor: Colors.red,
        amount: '1000',
        heading: 'Account Name',
        headingValue: 'Main Account',
        subheadingOne: 'Close Date',
        subheadingValueOne: 'Test 1',
        subheadingTwo: 'Type',
        subheadingValueTwo: 'Test 2',
        status: 'Won',
        subheadingIconOne: Icon(Icons.calendar_today),
        subheadingIconTwo: Container(),
        cardWidth: MediaQuery.of(context).size.width);
cardOnTapped(String heading) {
      print(heading);
    }
// Calling the card widget using the defined objects
opportunityDetailsCard(detailsCardData, cardOnTapped) - Return a single card

Author:
Rishabh Thakur
*/
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/color.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

import 'custom-widget-provider/custom-services.dart';

Widget opportunityDetailsCard(
    OpportunityDetailsCardData params, Function(String) callback) {
  return InkWell(
      onTap: callback(params.heading),
      child: Container(
        height: params.height,
        width: params.cardWidth,
        decoration: BoxDecoration(
            color: params.backgroundColor,
            borderRadius: BorderRadius.circular(params.cardRadius)),
        padding: EdgeInsets.all(params.padding),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Center(
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Text(
                    params.amount,
                    style: GoogleFonts.getFont(checkFonts(params.amountTextFamily),
                        color: params.amountTextColor,
                        fontSize: params.amountTextSize,
                        fontWeight: params.amountTextWeight),
                  ),
                  Spacer(
                    flex: 1,
                  ),
                  RaisedButton(
                      onPressed: () {},
                      child: Text(
                        params.status,
                        style: GoogleFonts.getFont( checkFonts(params.amountTextFamily),
                            fontSize: params.statusTextSize,
                            color: params.statusTextColor,
                            fontWeight: params.statusTextWeight),
                      ),
                      color: SalesforceColor.black,
                      shape: RoundedRectangleBorder(
                          borderRadius:
                              BorderRadius.circular(params.statusRadius)))
                ],
              ),
            ),
            SizedBox(
              height: 20,
            ),
            Text(
              params.heading,
              style: GoogleFonts.getFont(checkFonts(params.amountTextFamily),
                  color: params.headingTextColor,
                  fontSize: params.headingTextSize,
                  fontWeight: params.headingTextWeight),
            ),
            SizedBox(
              height: 8,
            ),
            Text(
              params.headingValue,
              style: GoogleFonts.getFont(checkFonts(params.amountTextFamily),
                  color: params.headingValueTextColor,
                  fontSize: params.headingValueTextSize,
                  fontWeight: params.headingValueTextWeight),
            ),
            SizedBox(
              height: 20,
            ),
            Row(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Text(
                        params.subheadingOne,
                        style: GoogleFonts.getFont(checkFonts(params.amountTextFamily),
                            color: params.subheadingOneTextColor,
                            fontSize: params.subheadingOneTextSize,
                            fontWeight: params.subheadingOneTextWeight),
                      ),
                      SizedBox(
                        height: 20,
                      ),
                      Text(
                        params.subheadingTwo,
                        style: GoogleFonts.getFont(checkFonts(params.amountTextFamily),
                            color: params.subheadingTwoTextColor,
                            fontSize: params.subheadingTwoTextSize,
                            fontWeight: params.subheadingTwoTextWeight),
                      )
                    ],
                  ),
                  SizedBox(
                    width: 20,
                  ),
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Text(params.subheadingValueOne,
                          style: GoogleFonts.getFont(checkFonts(params.amountTextFamily),
                              color: params.subheadingValueOneTextColor,
                              fontSize: params.subheadingValueOneTextSize,
                              fontWeight: params.subheadingValueOneTextWeight)),
                      SizedBox(
                        height: 20,
                      ),
                      Text(params.subheadingValueTwo,
                          style: GoogleFonts.getFont(checkFonts(params.amountTextFamily),
                              color: params.subheadingValueTwoTextColor,
                              fontSize: params.subheadingValueTwoTextSize,
                              fontWeight: params.subheadingValueTwoTextWeight)),
                    ],
                  ),
                  SizedBox(
                    width: 13,
                  ),
                  Column(
                    children: <Widget>[
                      params.subheadingIconOne,
                      SizedBox(height: 20),
                      params.subheadingIconTwo
                    ],
                  )
                ]),
          ],
        ),
      ));
}
