/*
Description:
Composite card widget that follows a two column structure.
THe two columns can intake a single widget or an array of widgets (Switch, Text Box, Check box, Radio Button).

Imports:
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/view/composite-widgets/custom-compositeCard.dart';

Usage:
The user has to pass in the division of the two columns using the flex values for the two columns.
This array of widgets can be a single widget like an individual widget or a Container or multiple widgets in an array format.
Optional parameters like margin, shadowColor textSpacing etc can be used to modify the look and feel of each card.

// Defining the object for the composite card widget
   List<CustomcompositeCardParameters> listcards = [];
    CustomcompositeCardParameters card1 = new CustomcompositeCardParameters(
        flexColumn1: 3,
        flexColumn2: 7,
        cardColor: Colors.white,
        rightHandWidgets: [
          Icon(
            Icons.home,
            color: Colors.black,
          ),
          Icon(
            Icons.alarm,
            color: Colors.black,
          )
        ],
        leftHandWidgets: [
          Text('Home'),
          Text('Clock')
        ]);

    listcards.add(card1);

// Calling the composite card widget
compositeCard(listcards)

Author:
Rishabh Thakur

*/

import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/consts.dart' as cons;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget compositeCard(List<CustomcompositeCardParameters> cardList) {
  List<Card> cards = [];
  var card;
  var cardvar;
  if (cardList == null || cardList.length == 0) {
    return Card(
      color: mediumGreyThemeData().iconTheme.color,
      child: Row(
        children: <Widget>[
          Expanded(
            flex: cons.DIVS,
            child: Checkbox(
              value: cons.MAX_Length_Enforced,
              activeColor: Colors.red,
              onChanged: (bool value) {},
            ),
          ),
          Spacer(),
          Expanded(
            flex: cons.DIVS,
            child: Checkbox(
              value: cons.MAX_Length_Enforced,
              activeColor: Colors.red,
              onChanged: (bool value) {},
            ),
          )
        ],
      ),
    );
  } else {
    for (cardvar = 0; cardvar < cardList.length; cardvar++) {
      print(cardList[cardvar].leftHandWidgets.length);
      card = new Card(
        margin: (cardList[cardvar].margin != null)
            ? EdgeInsets.all(cardList[cardvar].margin)
            : EdgeInsets.all(cons.heightTen),
        elevation: (cardList[cardvar].elevation != null)
            ? cardList[cardvar].elevation
            : cons.heightFive,
        color: (cardList[cardvar].cardColor != null)
            ? cardList[cardvar].cardColor
            : mediumGreyThemeData().accentIconTheme.color,
        child: Row(
          children: <Widget>[
            Expanded(
              flex: (cardList[cardvar].flexColumn1 != null)
                  ? cardList[cardvar].flexColumn1
                  : cons.DIVS,
              child: (cardList[cardvar].leftHandWidgets != null &&
                      cardList[cardvar].leftHandWidgets.length != 0)
                  ? Column(
                      mainAxisSize: MainAxisSize.min,
                      children: cardList[cardvar].leftHandWidgets)
                  : Checkbox(
                      value: cons.MAX_Length_Enforced,
                      activeColor: Colors.red,
                      onChanged: (bool value) {},
                    ),
            ),
            Spacer(),
            Expanded(
              flex: (cardList[cardvar].flexColumn2 != null)
                  ? cardList[cardvar].flexColumn2
                  : cons.DIVS,
              child: (cardList[cardvar].rightHandWidgets != null &&
                      cardList[cardvar].rightHandWidgets.length != 0)
                  ? Column(
                      mainAxisSize: MainAxisSize.min,
                      children: cardList[cardvar].rightHandWidgets)
                  : Checkbox(
                      value: cons.MAX_Length_Enforced,
                      activeColor: Colors.red,
                      onChanged: (bool value) {},
                    ),
            )
          ],
        ),
      );
      cards.add(card);
    }
    return Column(
      children: cards,
      mainAxisSize: cons.mainAxis_size,
    );
  }
}
