/*
Description:

Displays a dialog containing a Material Design date picker.When the date picker is first displayed, it will show the month of initialDate, with initialDate selected.


Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-datePicker.dart';

Usage:
The startYear & startMonth are for the firstDate which is the earliest allowable date. The endMonth & endMonth are for the lastDate which  is the latest allowable date. initialDate must either fall between these dates, or be equal to one of them.
The parameters such as confirmText,cancelText,hintText,onbodyColor,headerColor,bodybgColor and TextStyle of day,month,selectedDate,etc can be passed using the 'DatePickerParameters' class.
The date picker is passed as a Voidcallback to the pressed control of any widget.

void Function(DateTime) onSelect is used to return the date selected.

- Defining the callback and Date Picker objects

 DatePickerParameters datePickerObject = new DatePickerParameters(
        startMonth: 2,
        startYear: 2002,
        endMonth: 12,
        endYear: 2060,
        headerColor: Colors.pink,
        onBodyColor: Colors.black,
        bodybgColor: Colors.white,
        hintText: 'Select a date',
        confirmText: 'Select',
        cancelText: 'Cancel',
        dayTextStyle: GoogleFonts.getFont('Roboto',fontWeight: FontWeight.bold, fontSize: 15),
        monthTextStyle: GoogleFonts.getFont('Roboto',fontWeight: FontWeight.bold, fontSize: 20),
        selectedDateStyle: GoogleFonts.getFont('Roboto',fontWeight: FontWeight.bold, fontSize: 30),
        hintTextStyle: GoogleFonts.getFont('Roboto',fontWeight: FontWeight.bold, fontSize: 15));

    onDateSelect(DateTime t) {
      print(t);
    }
    FlatButtonParameters datepickerButton = new FlatButtonParameters(child: Text('Choose date',style: GoogleFonts.getFont('Roboto',color: Colors.white),),color: Colors.pink,height: 30);
    onPressDatePickerButton(bool b){
      customDatePicker(datePickerObject, context, onDateSelect);

    }

-Sample Implementation

customFlatButton(datepickerButton, onPressDatePickerButton, null)


Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/consts.dart' as consts;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

customDatePicker(DatePickerParameters param, BuildContext context,
    void Function(DateTime) onSelect) async {
  if (param == null && onSelect == null || param == null) {
    DateTime date = await showDatePicker(
      context: context,
      firstDate: DateTime(consts.start_year, consts.start_month, consts.one,
          consts.zero, consts.zero, consts.zero),
      lastDate: DateTime(consts.end_year, consts.end_month, consts.one,
          consts.zero, consts.zero, consts.zero),
      initialDate: DateTime.now(),
      builder: (BuildContext context, Widget child) {
        return Theme(
          data: Theme.of(context).copyWith(
            primaryColor: Theme.of(context).primaryColor,
            accentColor: Theme.of(context).accentColor,
            colorScheme: ColorScheme.light(
              primary: Theme.of(context).backgroundColor,
            ),
            dialogBackgroundColor: Theme.of(context).canvasColor,
            textTheme: TextTheme(
              subtitle1:
                  GoogleFonts.getFont('Roboto',color: Theme.of(context).accentIconTheme.color),
              bodyText2:
                  GoogleFonts.getFont('Roboto',color: Theme.of(context).accentIconTheme.color),
              caption:
                  GoogleFonts.getFont('Roboto',color: Theme.of(context).accentIconTheme.color),
            ),
            buttonTheme: ButtonThemeData(textTheme: ButtonTextTheme.primary),
          ),
          child: child,
        );

        //dialogBackgroundColor: Colors.white,//Background color
      },
    );

    if (date != null) {
      print(date);
    }
  } else {
    DateTime date = await showDatePicker(
      confirmText: param.confirmText,
      cancelText: param.cancelText,
      helpText: param.hintText,
      context: context,
      firstDate: DateTime(
          param.startYear != null ? param.startYear : consts.start_year,
          param.startMonth != null ? param.startMonth : consts.start_month,
          consts.one,
          consts.zero,
          consts.zero,
          consts.zero),
      lastDate: DateTime(
          param.endYear != null ? param.endYear : consts.end_year,
          param.endMonth != null ? param.endMonth : consts.end_month,
          consts.one,
          consts.zero,
          consts.zero,
          consts.zero),
      initialDate: DateTime(
          param.initialYear != null ? param.initialYear : consts.initial_year,
          param.initialMonth != null
              ? param.initialMonth
              : consts.initial_month,
          consts.one,
          consts.zero,
          consts.zero,
          consts.zero),
      builder: (BuildContext context, Widget child) {
        return Theme(
          data: Theme.of(context).copyWith(
            colorScheme: ColorScheme.light(
              primary: (param.headerColor != null)
                  ? param.headerColor
                  : Theme.of(context).primaryColor,
              onPrimary: (param.onHeaderColor != null)
                  ? param.onHeaderColor
                  : Theme.of(context).primaryTextTheme.subtitle1.color,
              onSurface: (param.onBodyColor != null)
                  ? param.onBodyColor
                  : Theme.of(context).textTheme.caption.color,
            ),
            dialogBackgroundColor: (param.bodybgColor != null)
                ? param.bodybgColor
                : Theme.of(context).canvasColor,
            textTheme: TextTheme(
              subtitle2: param.monthTextStyle != null
                  ? param.monthTextStyle
                  : Theme.of(context).textTheme.subtitle2,
              //month
              headline4: param.selectedDateStyle != null
                  ? param.selectedDateStyle
                  : Theme.of(context).textTheme.headline4,
              //onprimary
              overline: param.hintTextStyle != null
                  ? param.hintTextStyle
                  : Theme.of(context).textTheme.overline,
              //hint
              caption: param.dayTextStyle != null
                  ? param.dayTextStyle
                  : Theme.of(context).textTheme.caption,
              button: param.buttonTextStyle != null
                  ? param.buttonTextStyle
                  : Theme.of(context).textTheme.button,
            ),
            buttonTheme: ButtonThemeData(
              textTheme: ButtonTextTheme.primary,
            ),
          ),
          child: child,
        );
      },
    );
    if (date != null) {
      onSelect(date);
    }
  }
}
