import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

import 'custom-widget-provider/custom-services.dart';

class CustomDropdownButton extends StatefulWidget {
  final DropDownParameters param;
  final void Function(int, String) callback;

  CustomDropdownButton(this.param, this.callback) : super();

  @override
  _CustomDropdownButton createState() => _CustomDropdownButton(param, callback);
}

class _CustomDropdownButton extends State<CustomDropdownButton> {
  final DropDownParameters param;
  void Function(int, String) callback;

  _CustomDropdownButton(this.param, this.callback);

  String dropdownValue;

  Widget build(BuildContext context) {
    if (param == null) {
      return Container(
        height: 60,
        width: 150,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.all(Radius.circular(10)),
            color: Theme.of(context).buttonColor,
            boxShadow: [
              BoxShadow(
                  color: mediumGreyThemeData().scaffoldBackgroundColor,
                  offset: Offset(
                    0,
                    0,
                  ),
                  blurRadius: 0,
                  spreadRadius: 0)
            ]),
        child: Theme(
          data: Theme.of(context).copyWith(
              canvasColor: Theme.of(context).canvasColor,
              // background color for the dropdown items
              buttonTheme: ButtonTheme.of(context).copyWith(
                alignedDropdown: true,
              )),
          child: DropdownButtonHideUnderline(
            child: DropdownButton<String>(
              items: <String>['Option A', 'Option B', 'Option C', 'Option D']
                  .map<DropdownMenuItem<String>>((String value) {
                return DropdownMenuItem<String>(
                  value: value,
                  child: Text(value,
                      overflow: TextOverflow.ellipsis,
                      style: GoogleFonts.getFont('Roboto',
                        fontSize: 18,
                        color: Theme.of(context).textTheme.bodyText1.color,
                      )),
                );
              }).toList(),
              hint: Text(
                "Sample Text",
                overflow: TextOverflow.ellipsis,
              ),
              // setting hint
              onChanged: (String value) {
                setState(() {
                  dropdownValue = value;
                  print(dropdownValue);
                });
              },

              value: dropdownValue,
            ),
          ),
        ),
      );
    } else {
      return Container(
        height: ((widget.param.height) != null) ? widget.param.height : 60,
        width: ((widget.param.width) != null) ? widget.param.width : 300,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.all(Radius.circular(
                (widget.param.borderRadius != null)
                    ? widget.param.borderRadius
                    : 10)),
            color: (widget.param.fillColor != null)
                ? widget.param.fillColor
                : Theme.of(context).buttonColor,
            boxShadow: [
              BoxShadow(
                  color: (widget.param.shadowColor == null)
                      ? mediumGreyThemeData().scaffoldBackgroundColor
                      : widget.param.shadowColor,
                  offset: Offset(
                      (widget.param.shadowOffsetX == null)
                          ? 0
                          : widget.param.shadowOffsetX,
                      (widget.param.shadowOffsetY == null)
                          ? 0
                          : widget.param.shadowOffsetY),
                  blurRadius: (widget.param.shadowBlurRadius == null)
                      ? 0
                      : widget.param.shadowBlurRadius,
                  spreadRadius: (widget.param.shadowSpreadRadius == null)
                      ? 0
                      : widget.param.shadowSpreadRadius)
            ]),
        child: Theme(
            data: Theme.of(context).copyWith(
                canvasColor: (widget.param.itemsBgColor != null)
                    ? widget.param.itemsBgColor
                    : Theme.of(context).canvasColor,
                // background color for the dropdown items
                buttonTheme: ButtonTheme.of(context).copyWith(
                  alignedDropdown: true,
                )),
            child: DropdownButtonHideUnderline(
              child: DropdownButton<String>(
                key: widget.param.key,

                items: widget.param.itemsList.map((String value) {
                  return DropdownMenuItem<String>(
                    value: value,
                    child: (param.listType == 'String')
                        ? Text(
                            value,
                            overflow: TextOverflow.ellipsis,
                            style: GoogleFonts.getFont('Roboto',
                                fontSize: (widget.param.fontSize != null)
                                    ? widget.param.fontSize
                                    : 18.0,
                                color: (widget.param.textColor != null)
                                    ? widget.param.textColor
                                    : Colors.black,
                                fontWeight: widget.param.fontWeight),
                          )
                        : (param.listType == 'NetworkImage')
                            ? Image.network(
                                value,
                                height: (widget.param.imageHeight == null)
                                    ? 60
                                    : widget.param.imageHeight,
                                width: (widget.param.imageWidth == null)
                                    ? 90
                                    : widget.param.imageWidth,
                              )
                            : (param.listType == 'AssetImage')
                                ? Image.asset(
                                    value,
                                    height: (widget.param.imageHeight == null)
                                        ? 60
                                        : widget.param.imageHeight,
                                    width: (widget.param.imageWidth == null)
                                        ? 90
                                        : widget.param.imageWidth,
                                  )
                                : Text(
                                    value,
                                    style: GoogleFonts.getFont('Roboto',
                                      fontSize: (widget.param.fontSize != null)
                                          ? widget.param.fontSize
                                          : 18,
                                      color: (param.textColor != null)
                                          ? param.textColor
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .color,
                                      fontWeight: (param.fontWeight != null)
                                          ? param.fontWeight
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .fontWeight,
                                      fontStyle: (param.fontStyle != null)
                                          ? param.fontStyle
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .fontStyle,
                                    ),
                                  ),
                  );
                }).toList(),
                hint: Text(
                  (widget.param.hintText != null)
                      ? widget.param.hintText
                      : "Sample Text",
                  overflow: TextOverflow.ellipsis,
                  textAlign: (widget.param.textAlign == null)
                      ? TextAlign.left
                      : widget.param.textAlign,
                  style: GoogleFonts.getFont('Roboto',
                    fontSize: (widget.param.fontSize != null)
                        ? widget.param.fontSize
                        : 18,
                    color: (param.hintTextColor != null)
                        ? param.hintTextColor
                        : Theme.of(context).textTheme.subtitle1.color,
                    fontWeight: (param.hintFontWeight != null)
                        ? param.hintFontWeight
                        : Theme.of(context).textTheme.subtitle1.fontWeight,
                    fontStyle: (param.hintFontStyle != null)
                        ? param.hintFontStyle
                        : Theme.of(context).textTheme.subtitle1.fontStyle,
                  ),
                ),
                // setting hint
                onChanged: (String value) {
                  setState(() {
                    dropdownValue = value;
                    widget.callback(
                        widget.param.itemsList.indexOf(value), dropdownValue);
                  });
                },

                value: dropdownValue,
              ),
            )),
      );
    }
  }
}
