/*
Description:
A widget that creates a widget for fingerprint Authentication. The phone or the emulator on which it will be running must have a registered 
and authentic fingerprint as a pre-requisite for running this widget. 

Also the following changes are to be made in order to run this widget:

file: pubspec.yaml
change: Add local_auth: ^0.6.1(version) under dependencies.

file: flutter-library\android\app\src\main\kotlin\com\example\flutter_store\MainActivity.kt
change: 
1. import io.flutter.embedding.android.FlutterFragmentActivity
2. class MainActivity: FlutterFragmentActivity() instead of class MainActivity: FlutterActivity() 

file: (flutter-library\android\app\src\main\AndroidManifest.xml) and (flutter-library\android\app\src\profile\AndroidManifest.xml)
change: Add <uses-permission android:name="android.permission.USE_BIOMETRIC"/> right next to other permissions like <uses-permission android:name="android.permission.CAMERA" />
which are already present. 

Usage:
The user can pass in Widget to be tapped, Text to be displayed .
The user can also pass on parameters like Icon color, Icon size, Text Color, Text Size and Background Color.
The user also passes a callback function which is invoked when CustomFingerprint is used.
- The widget returns the authentication status of True/False when submitted.

   onAuthenticated(bool sBool) {
      if (sBool) {
        print(sBool);
      }
    }

   CustomFingerprintParameters params = new CustomFingerprintParameters( backgroundColor: Colors.blueGrey, textColor: Colors.redAccent , authText: "Fingerprint Authentication", tapWidget: Icon(Icons.fingerprint, size: 60,),textSize: 32);
    
   CustomFingerprint(authCallback: onAuthenticated, param: params,)

    Imports:
    import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
    import 'package:rapid_widgets_library/theme.dart';
    import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
    import 'package:local_auth/local_auth.dart';
    import 'custom-fingerprint.dart';

Author:
Anubhav Sinha
*/

import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:local_auth/local_auth.dart';

class CustomFingerprint extends StatefulWidget {
  final CustomFingerprintParameters param;
  final void Function(bool) authCallback;

  const CustomFingerprint({
    Key key,
    this.param,
    this.authCallback,
  }) : super(key: key);

  @override
  _CustomFingerprintState createState() => _CustomFingerprintState(
        this.param,
        this.authCallback,
      );
}

class _CustomFingerprintState extends State<CustomFingerprint> {
  CustomFingerprintParameters param;
  void Function(bool) authCallback;
  _CustomFingerprintState(
    this.param,
    this.authCallback,
  );
  final LocalAuthentication localAuth = LocalAuthentication();
  @override
  Widget build(BuildContext context) {
    if (param == null) {
      return Scaffold(
        backgroundColor: Theme.of(context).backgroundColor,
        body: GestureDetector(
          onTap: () async {
            bool weCanCheckBiometrics = await localAuth.canCheckBiometrics;

            if (weCanCheckBiometrics) {}
            authCallback(true);
          },
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: <Widget>[
              Icon(
                Icons.fingerprint,
                size: 68.0,
                color: Theme.of(context).selectedRowColor,
              ),
              Text(
                "Tap to Login to App",
                style: GoogleFonts.getFont('Roboto',
                  fontSize: 32.0,
                  color: Theme.of(context).selectedRowColor,
                ),
                textAlign: TextAlign.center,
              ),
            ],
          ),
        ),
      );
    } else {
      return Scaffold(
        backgroundColor: (param.backgroundColor != null)
            ? param.backgroundColor
            : Theme.of(context).backgroundColor,
        body: GestureDetector(
          onTap: () async {
            bool weCanCheckBiometrics = await localAuth.canCheckBiometrics;

            if (weCanCheckBiometrics) {}
            authCallback(true);
          },
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: <Widget>[
              (param.tapWidget != null)
                  ? param.tapWidget
                  : Icon(
                      Icons.fingerprint,
                      size: 68.0,
                      color: Theme.of(context).selectedRowColor,
                    ),
              Text(
                (param.authText != null)
                    ? param.authText
                    : "Tap to Login to App",
                style: GoogleFonts.getFont('Roboto',
                  fontSize: (param.textSize != null) ? param.textSize : 32.0,
                  color: (param.textColor != null)
                      ? param.textColor
                      : Theme.of(context).selectedRowColor,
                ),
                textAlign: TextAlign.center,
              ),
            ],
          ),
        ),
      );
    }
  }
}
