import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

import 'custom-widget-provider/custom-services.dart';

Widget customFlatButton(
  FlatButtonParameters textParameters,
  void Function(bool) onPress,
  void Function(bool) onLongPress,
) {
  return Container(
    alignment: textParameters.cAlign,
    decoration: BoxDecoration(
        color: (textParameters.ContainerColor!=null)?textParameters.ContainerColor:Colors.transparent,
        border: Border.all(color: (textParameters.BorderColor!=null)?textParameters.BorderColor:Colors.transparent),
        borderRadius: BorderRadius.all(
          Radius.circular((textParameters.border_radius!=null)?textParameters.border_radius:0),
        ),
        boxShadow: [
          (textParameters.opacity!=0)?BoxShadow(
            color: (textParameters.boxshadowcolor!=null)?textParameters.boxshadowcolor.withOpacity(textParameters.opacity):Colors.transparent,
            offset: const Offset(
              15.0,
              10.0,
            ),
            blurRadius: (textParameters.blur_radius!=null)?textParameters.blur_radius:0,
            spreadRadius: (textParameters.spread_radius!=null)?textParameters.spread_radius:0,
          ):BoxShadow(
            color: (textParameters.boxshadowcolor!=null)?textParameters.boxshadowcolor:Colors.transparent,
            offset: const Offset(
              5.0,
              5.0,
            ),
            blurRadius: (textParameters.blur_radius!=null)?textParameters.blur_radius:0,
            spreadRadius: (textParameters.spread_radius!=null)?textParameters.spread_radius:0,
          ),
          /*BoxShadow(
            color: (textParameters.boxshadowcolor!=null)?textParameters.boxshadowcolor.withOpacity(0.5):Colors.transparent,
            offset: const Offset(
              15.0,
              10.0,
            ),
            blurRadius: (textParameters.blur_radius!=null)?textParameters.blur_radius:0,
            spreadRadius: (textParameters.spread_radius!=null)?textParameters.spread_radius:0,
          ), *///BoxShadow
        ]
    ),
    child: FlatButton(
      padding: EdgeInsets.all(0),
      onPressed: () {
        return (onPress != null) ? onPress(true) : null;
      },
      onLongPress: () {
        return (onLongPress != null) ? onLongPress(true) : null;
      },
      highlightColor: textParameters.highlightColor,
      focusColor: textParameters.focusColor,
      splashColor: textParameters.splashColor,
      hoverColor: textParameters.hoverColor,
      shape: new RoundedRectangleBorder(
        borderRadius: new BorderRadius.circular(textParameters.border_radius!=null?textParameters.border_radius:0),
      ),
      child: Wrap(
        children: [
          //icon1
          if(textParameters.icon1!=null || textParameters.icon1_size!=0 )
            Padding(
              padding:  EdgeInsets.fromLTRB(
                (textParameters.pad_val_l_wrap_icon!=null)?textParameters.pad_val_l_wrap_icon:0,
                (textParameters.pad_val_top_wrap_icon!=null)?textParameters.pad_val_top_wrap_icon:0,
                (textParameters.pad_val_r_wrap_icon!=null)?textParameters.pad_val_r_wrap_icon:0,
                (textParameters.pad_val_bottom_wrap_icon!=null)?textParameters.pad_val_bottom_wrap_icon:0,
              ),
              child: Icon(textParameters.icon1, color: (textParameters.icon1_color!=null)?textParameters.icon1_color:Colors.grey,size: textParameters.icon1_size,),
            ),


          //TEXT
          Padding(
            padding:  EdgeInsets.fromLTRB(
              (textParameters.pad_val_l_wrap_text!=null)?textParameters.pad_val_l_wrap_text:0,
              (textParameters.pad_val_top_wrap_text!=null)?textParameters.pad_val_top_wrap_text:0,
              (textParameters.pad_val_r_wrap_text!=null)?textParameters.pad_val_r_wrap_text:0,
              (textParameters.pad_val_bottom_wrap_text!=null)?textParameters.pad_val_bottom_wrap_text:0,
            ),
            child: Text(
              (textParameters.text != null) ? textParameters.text : 'Hello',
              maxLines: (textParameters.maxLines != null) ? textParameters.maxLines : 3,
              textAlign: (textParameters.textAlign != null)
                  ? textParameters.textAlign
                  : TextAlign.start,
              style: GoogleFonts.getFont(
                (textParameters.fontFamily != null)
                    ? checkFonts(textParameters.fontFamily)
                    : 'Roboto',
                height: (textParameters.height != null) ? textParameters.height : 1.0,
                color: (textParameters.textColor != null)
                    ? textParameters.textColor
                    : Colors.black,
                fontSize:
                (textParameters.fontSize != null) ? textParameters.fontSize : 12.0,
                fontWeight: (textParameters.fontWeight != null)
                    ? textParameters.fontWeight
                    : FontWeight.normal,
                fontStyle: (textParameters.fontStyle != null)
                    ? textParameters.fontStyle
                    : FontStyle.normal,

              ),
            ),
          ),

          //icon2

          if(textParameters.icon2!=null || textParameters.icon2_size !=0)
            Padding(
              padding:  EdgeInsets.fromLTRB(
                (textParameters.pad_val_l_wrap_icon!=null)?textParameters.pad_val_l_wrap_icon:0,
                (textParameters.pad_val_top_wrap_icon!=null)?textParameters.pad_val_top_wrap_icon:0,
                (textParameters.pad_val_r_wrap_icon!=null)?textParameters.pad_val_r_wrap_icon:0,
                (textParameters.pad_val_bottom_wrap_icon!=null)?textParameters.pad_val_bottom_wrap_icon:0,
              ),
              child: Icon(textParameters.icon2,color: (textParameters.icon2_color!=null)?textParameters.icon2_color:Colors.grey,size: textParameters.icon2_size,),
            )

        ],
      ),
    ),


  );
}
