/*
Widget Name:
- Custom Flip Card

Description:
- Custom Flip card is a card animation that gives an element the effect of flipping to the other side upon any interaction.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-flipcard.dart';

Usage:
-Creating the object for the card

     onclickCardBtn(int nIndex, String sText) {print(nIndex);print(sText);}
    MaterialCardData Obj1 = new MaterialCardData(
        title: "Colosseum",
        subtitle: "The Colosseum in Rome was built in the first century by order of the Emperor Vespasian",
        containerHeight: 250.0,
        containerWidth: 250.0,
        containerDecoration: BoxDecoration(
          boxShadow: [
            BoxShadow(
                color: Colors.white,
                blurRadius: 10,
                offset: Offset.zero)
          ],
          borderRadius: BorderRadius.circular(20),
          color: Colors.white,
        ),
        textStyle1: GoogleFonts.getFont('Roboto',
          color: Colors.black,
          fontSize: 20,
          fontWeight: FontWeight.bold,
        ),
        textStyle2: GoogleFonts.getFont('Roboto',
          color: Colors.black,
          fontSize: 16.0,
        ),
        textStyle3: GoogleFonts.getFont('Roboto',
          color: Colors.white,
          fontSize: 16.0,
        ),
        btnText: "View",
        btnTextColor: Colors.black,
        btnColor: Colors.black,
        margin1: 0,
        padding1: 0,
        imgHeight: 170,
        imgWidth: 170,
        imgType: "Network",
        imgPath: "https://cdn.britannica.com/75/75775-050-1FC4B34B/Colosseum-Rome.jpg");


    -Object call for the widget
        body: customFlipCardWidget(Obj1, onclickCardBtn),

    ****Note:
    - imgType decides weather the image source is network image or asset image.

    Author:
    Satyabrat Padhy
*/

import 'dart:math';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/consts.dart' as constants;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget customFlipCardWidget(
    MaterialCardData data, void Function(int, String) callback) {
  // Here data is the contents to be shown coming as a parameter for this widget.
  ImageProvider image;
  if (data.imgType != null && data.imgType == constants.Asset ||
      data.imgType == constants.asset) {
    image = (data.imgPath == null)
        ? AssetImage(constants.cardImagePath)
        : AssetImage(
            data.imgPath,
          );
  } else if (data.imgType != null && data.imgType == constants.Network ||
      data.imgType == constants.network) {
    image = (data.imgPath == null)
        ? NetworkImage(constants.networkCardImagePath)
        : NetworkImage(data.imgPath);
  } else {
    image = NetworkImage(constants.networkCardImagePath);
  }

  return Container(
    height: (data.containerHeight != null)
        ? data.containerHeight
        : constants.heightOneEighty,
    width: (data.containerWidth != null)
        ? data.containerWidth
        : constants.heightOneEighty,
    decoration: (data.containerDecoration != null)
        ? data.containerDecoration
        : BoxDecoration(
            color: mediumGreyThemeData().backgroundColor,
            border: Border.all(
              color: mediumGreyThemeData().primaryColorDark,
              width: constants.heightOne,
            ),
            borderRadius: BorderRadius.circular(
                constants.heightFive * constants.heightThree),
          ),
    child: FlipCard(
      direction: (data.flipDirection != null)
          ? data.flipDirection
          : FlipDirection.HORIZONTAL,
      speed:
          (data.flipSpeed != null) ? data.flipSpeed : constants.speedThousand,
      onFlipDone: (status) {
        print(status);
      },
      front: Container(
        decoration: (data.decoration1 != null)
            ? data.decoration1
            : BoxDecoration(
                color: mediumGreyThemeData().backgroundColor,
                borderRadius: BorderRadius.all(Radius.circular(
                    constants.heightFive * constants.heightThree)),
              ),
        child: AspectRatio(
          aspectRatio: 4 / 3,
          child: Semantics(
            label: (data.title != null) ? data.title : constants.cardTitle,
            child: Container(
              height: (data.imgHeight != null)
                  ? data.imgHeight
                  : constants.heightFifty * constants.heightThree,
              margin: EdgeInsets.all((data.margin1 != null)
                  ? data.margin1
                  : constants.heightFifty),
              padding: EdgeInsets.all((data.padding1 != null)
                  ? data.padding1
                  : constants.heightTwenty),
              decoration: BoxDecoration(
                image: DecorationImage(
                  image: (image != null)
                      ? image
                      : NetworkImage(constants.networkCardImagePath),
                ),
              ),
            ),
          ),
        ),
      ),
      back: Padding(
        padding: EdgeInsets.all(
            (data.padding2 != null) ? data.padding2 : constants.heightTwenty),
        child: Column(
          children: <Widget>[
            SizedBox(
              height: constants.heightTwenty,
            ),
            Text(
              (data.title != null) ? data.title : constants.cardTitle,
              style: (data.textStyle1 != null)
                  ? data.textStyle1
                  : GoogleFonts.getFont('Roboto',
                      color: mediumGreyThemeData().textSelectionColor,
                      fontSize: constants.font_medium,
                      fontWeight: constants.fontBold,
                    ),
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightFive,
            ),
            Text(
              (data.subtitle != null) ? data.subtitle : constants.cardSubtitle,
              textAlign: TextAlign.start,
              style: (data.textStyle2 != null)
                  ? data.textStyle2
                  : GoogleFonts.getFont('Roboto',
                      color: mediumGreyThemeData().textSelectionColor,
                      fontSize: constants.fontSmall,
                    ),
              overflow: TextOverflow.ellipsis,
              maxLines: constants.maxLines,
              softWrap: true,
            ),
            SizedBox(
              height: constants.heightFourrty,
            ),
            Center(
              child: FlatButton(
                color: (data.btnColor != null)
                    ? data.btnColor
                    : mediumGreyThemeData().buttonColor,
                shape: (data.shapeButton != null)
                    ? data.shapeButton
                    : RoundedRectangleBorder(
                        borderRadius:
                            new BorderRadius.circular(constants.heightTwenty)),
                padding: EdgeInsets.symmetric(
                    vertical: constants.heightTwo * constants.heightTwo,
                    horizontal: constants
                        .heightFourrty), //adds padding inside the button
                child: Text(
                  data.btnText != null ? data.btnText : constants.cardBtnText,
                  style: (data.textStyle3 != null)
                      ? data.textStyle3
                      : GoogleFonts.getFont('Roboto',
                          color: mediumGreyThemeData().primaryColorDark,
                          fontSize: constants.fontMedium),
                ),
                onPressed: () =>
                    {callback(constants.intOne, constants.cardBtnText)},
              ),
            ),
          ],
        ),
      ),
    ),
  );
}

enum FlipDirection {
  VERTICAL,
  HORIZONTAL,
}

class AnimationCard extends StatelessWidget {
  AnimationCard({this.child, this.animation, this.direction});

  final Widget child;
  final Animation<double> animation;
  final FlipDirection direction;

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animation,
      builder: (BuildContext context, Widget child) {
        var transform = Matrix4.identity();
        transform.setEntry(constants.intThree, constants.intTwo, 0.001);
        if (direction == FlipDirection.VERTICAL) {
          transform.rotateX(animation.value);
        } else {
          transform.rotateY(animation.value);
        }
        return Transform(
          transform: transform,
          alignment: Alignment.center,
          child: child,
        );
      },
      child: child,
    );
  }
}

typedef void BoolCallback(bool isFront);

class FlipCard extends StatefulWidget {
  final Widget front;
  final Widget back;
  final int speed;
  final FlipDirection direction;
  final VoidCallback onFlip;
  final BoolCallback onFlipDone;
  final bool flipOnTouch;

  const FlipCard(
      {Key key,
      @required this.front,
      @required this.back,
      this.speed = constants.intFiveHundred,
      this.onFlip,
      this.onFlipDone,
      this.direction = FlipDirection.HORIZONTAL,
      this.flipOnTouch = true})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return FlipCardState();
  }
}

class FlipCardState extends State<FlipCard>
    with SingleTickerProviderStateMixin {
  AnimationController controller;
  Animation<double> _frontRotation;
  Animation<double> _backRotation;

  bool isFront = true;

  @override
  void initState() {
    super.initState();
    controller = AnimationController(
        duration: Duration(milliseconds: widget.speed), vsync: this);
    _frontRotation = TweenSequence(
      <TweenSequenceItem<double>>[
        TweenSequenceItem<double>(
          tween: Tween(begin: constants.buttonBorderRadius, end: pi / 2)
              .chain(CurveTween(curve: Curves.easeIn)),
          weight: constants.heightFifty,
        ),
        TweenSequenceItem<double>(
          tween: ConstantTween<double>(pi / 2),
          weight: constants.heightFifty,
        ),
      ],
    ).animate(controller);
    _backRotation = TweenSequence(
      <TweenSequenceItem<double>>[
        TweenSequenceItem<double>(
          tween: ConstantTween<double>(pi / 2),
          weight: constants.heightFifty,
        ),
        TweenSequenceItem<double>(
          tween: Tween(begin: -pi / 2, end: constants.buttonBorderRadius)
              .chain(CurveTween(curve: Curves.easeOut)),
          weight: constants.heightFifty,
        ),
      ],
    ).animate(controller);
    controller.addStatusListener((status) {
      if (status == AnimationStatus.completed ||
          status == AnimationStatus.dismissed) {
        if (widget.onFlipDone != null) widget.onFlipDone(isFront);
      }
    });
  }

  void toggleCard() {
    if (widget.onFlip != null) {
      widget.onFlip();
    }
    if (isFront) {
      controller.forward();
    } else {
      controller.reverse();
    }

    setState(() {
      isFront = !isFront;
    });
  }

  @override
  Widget build(BuildContext context) {
    final child = Stack(
      fit: StackFit.passthrough,
      children: <Widget>[
        _buildContent(front: true),
        _buildContent(front: false),
      ],
    );
    if (widget.flipOnTouch) {
      return GestureDetector(
        behavior: HitTestBehavior.translucent,
        onTap: toggleCard,
        child: child,
      );
    }
    return child;
  }

  Widget _buildContent({@required bool front}) {
    return IgnorePointer(
      ignoring: front ? !isFront : isFront,
      child: AnimationCard(
        animation: front ? _frontRotation : _backRotation,
        child: front ? widget.front : widget.back,
        direction: widget.direction,
      ),
    );
  }

  @override
  void dispose() {
    controller.dispose();
    super.dispose();
  }
}
