/*
Description:

Dynamically creates a Floating Action Button material widget which responds to a press.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-floatingActionButton.dart';

Usage:

The 'child' parameter accepts a widget to be displayed on the button and can be specified to be a Text, Icon,etc.
The parameters such as shape,mini,elevation,height,foregroundColor,backgroundColor,highlightColor,splashColor,etc can be passed using the class 'Floatingactionbuttonparam'.
onPress callback function can be passed which returns a 'true' value and can be used to define further actions to be performed on press.
A floating action button with default parameters is created if null is passed as Floatingactionbuttonparam.
- Defining the callback and Floating Action Button objects

onButtonPress(bool b){
      print(b);
    }

  Floatingactionbuttonparam btnObject = Floatingactionbuttonparam(child: Icon(Icons.call),foregroundColor: Colors.black,backgroundColor: Colors.yellow,mini: false,shape: CircleBorder(),hoverColor:Colors.orange);

- Object call for the widget

customFloatingActionButton(btnObject, onButtonPress)

Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/consts.dart' as con;
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/theme.dart';

Widget customFloatingActionButton(
    Floatingactionbuttonparam param, void Function(bool) onPress) {
  if (param == null && onPress == null) {
    return FloatingActionButton(
      autofocus: false,
      backgroundColor:
          mediumGreyThemeData().floatingActionButtonTheme.backgroundColor,
      child: Icon(con.icon_add),
      focusColor: mediumGreyThemeData().focusColor,
      foregroundColor:
          mediumGreyThemeData().floatingActionButtonTheme.foregroundColor,
      hoverColor: mediumGreyThemeData().hoverColor,
      isExtended: false,
      mini: false,
      onPressed: () {},
      shape: con.FloatingActionButtonShape,
      splashColor: mediumGreyThemeData().splashColor,
      heroTag: 'customFloatingActionButton',
    );
  } else {
    return FloatingActionButton(
      autofocus: (param.autofocus != null) ? param.autofocus : false,
      elevation: param.elevation,
      hoverElevation: param.hoverElevation,
      focusNode: param.focusNode,
      focusElevation: param.focusElevation,
      highlightElevation: param.highlightElevation,
      disabledElevation: param.disabledElevation,
      backgroundColor: (param.backgroundColor != null)
          ? param.backgroundColor
          : mediumGreyThemeData().floatingActionButtonTheme.backgroundColor,
      child: (param.child != null) ? param.child : Icon(con.icon_add),
      focusColor: (param.focusColor != null)
          ? param.focusColor
          : mediumGreyThemeData().focusColor,
      foregroundColor: (param.foregroundColor != null)
          ? param.foregroundColor
          : mediumGreyThemeData().floatingActionButtonTheme.foregroundColor,
      hoverColor: (param.hoverColor != null)
          ? param.hoverColor
          : mediumGreyThemeData().hoverColor,
      isExtended: (param.isExtended != null) ? param.isExtended : false,
      mini: (param.mini != null) ? param.mini : false,
      onPressed: () {
        return (onPress != null) ? onPress(true) : null;
      },
      shape:
          (param.shape != null) ? param.shape : con.FloatingActionButtonShape,
      splashColor: (param.splashColor != null)
          ? param.splashColor
          : mediumGreyThemeData().splashColor,
      heroTag: param.heroTag,
      tooltip: param.tooltip,
    );
  }
}
