import 'dart:convert';
import 'dart:io';
import 'dart:typed_data';
import 'package:path/path.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:flutter/cupertino.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:http/http.dart' as http;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

///------------- Use syntax For FilePicket Widget ------------------------------
///
/// DocumentUploadWidget(
///   buttonText: "Select Files", // [Required]
///   showSelectedFileNames: true, // If set false, it will now show selected file Name
/// ),
///-----------------------------------------------------------------------------

///---------------------- Packages Dependency ----------------------------------
/// @ permission_handler: ^8.2.5
/// @ file_picker: ^4.2.0
/// @ http: ^0.13.4
///-----------------------------------------------------------------------------


///-------------- Documents Upload Widget Call Class -------------------
/// @ Parameters for Document Upload Widget
/// @ [Required] Use [buttonText] to set button name.
/// @ [Optional] Use [textColor] to set button text color.
/// @ [Optional] Use [minWidth] to set button min width.
/// @ [Optional] Use [height] to set button min height.
/// @ [Optional] Use [fontSize] to set size of button text font.
/// @ [Optional] Use [fontWeight] to set weight of button text font.
/// @ [Optional] Use [elevation] to set button shadow.
/// @ [Optional] Use [buttonColor] to set button color.
/// @ [Optional] Use [borderRadius] to set overall button radius.
/// @ [Optional] Use [onPressed] if you want to use any other functionality instead of file picker.
/// @ [Optional] Use [showSelectedFileNames] for show selected file names.
/// @ [Optional] Use [apiUrl] for set server url for upload multiple files at once.
/// @ [Optional] Use [uploadKey] for set key for api. Default is 'files'.

class DocumentUploadWidget extends StatefulWidget {

  // String buttonText;
  // double fontSize;
  // FontWeight fontWeight;
  // Color textColor;
  // double height;
  // double minWidth;
  // double elevation;
  // Color buttonColor;
  // double borderRadius;
  // Function() onPressed;
  // bool showSelectedFileNames;
  // String apiUrl;
  // String uploadKey;
  //
  // DocumentUploadWidget({
  //   Key key,
  //   @required this.buttonText,
  //   this.fontSize,
  //   this.fontWeight,
  //   this.textColor,
  //   this.height,
  //   this.minWidth,
  //   this.elevation,
  //   this.buttonColor,
  //   this.borderRadius,
  //   this.onPressed,
  //   this.showSelectedFileNames,
  //   this.apiUrl,
  //   this.uploadKey
  // }) : super(key: key);

  final DocumentUploadParamsWidget documentUploadParamsWidget;

  const DocumentUploadWidget({this.documentUploadParamsWidget});

  @override
  State<DocumentUploadWidget> createState() => _DocumentUploadWidgetState();
}

class _DocumentUploadWidgetState extends State<DocumentUploadWidget> {
  dynamic selectedFiles;

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        MaterialButton(
          minWidth: widget.documentUploadParamsWidget.minWidth ?? 200.0,
          height: widget.documentUploadParamsWidget.height ?? 35,
          color: widget.documentUploadParamsWidget.buttonColor ?? Colors.blue,
          elevation: widget.documentUploadParamsWidget.elevation ?? 4.0,
          shape: RoundedRectangleBorder(
            borderRadius:BorderRadius.circular(widget.documentUploadParamsWidget.borderRadius??4.0),
          ),
          child: Text(
            widget.documentUploadParamsWidget.buttonText,
            style: GoogleFonts.getFont('Roboto',
                fontSize: widget.documentUploadParamsWidget.fontSize ?? 16.0,
                color: widget.documentUploadParamsWidget.textColor ?? Colors.white
            ),
          ),
          onPressed: widget.documentUploadParamsWidget.onPressed ??() => pickDocumentFromFiles(context),
        ),
        if(widget.documentUploadParamsWidget.showSelectedFileNames == true && selectedFiles != null)
          for(int i=0; i<selectedFiles.length; i++)
            Text(basename(selectedFiles[i].path), style:  GoogleFonts.getFont('Roboto',color: Colors.grey),)

      ],
    );
  }

  pickDocumentFromFiles(BuildContext context) async {
    dynamic _selectedFilesObj = await getFiles(
        context,
        {},
        {},
        widget.documentUploadParamsWidget.apiUrl,
        widget.documentUploadParamsWidget.uploadKey??"files"
    );
    print(_selectedFilesObj);
    // setState(() => selectedFiles = _selectedFilesObj);

    /// Check if Selected Files and Api Url is not empty.
    /// Call to upload files in server using API.
    /// Default upload Key "files", if required use different one.
    /// [uploadKey] is optional
    // if(widget.documentUploadParamsWidget.apiUrl != null && selectedFiles != null){
    //   List<dynamic> uploadStatus = await uploadMultipleFilesUsingAPI(
    //       context,
    //       selectedFiles,
    //       {},
    //       {},
    //       widget.documentUploadParamsWidget.apiUrl,
    //       widget.documentUploadParamsWidget.uploadKey??"files"
    //   );
    //   print("Selected Files: ${uploadStatus.toString()}");
    // }

  }
}


Future<dynamic> getFiles(
    BuildContext context,
    Map<String, String> dataParameters,
    Map<String, String> headers,
    String apiUrl, String uploadKey
  ) async {

  dynamic selectedImage;

  /// @ Checking condition for web platform.
  /// @ Else it will execute as mobile platform.
  if (kIsWeb) {

    selectedImage = await multipleFilePicker(
        context,
        dataParameters,
        headers,
        apiUrl,
        uploadKey
    );
  } else {
    bool storagePermissionStatus = await checkStoragePermission(context);
    if (storagePermissionStatus) {
      selectedImage = await multipleFilePicker(
          context,
          dataParameters,
          headers,
          apiUrl,
          uploadKey
      );
    } else {
      bool requestStorageStatus = await requestStoragePermission(context);
      if (requestStorageStatus) {
        selectedImage = await multipleFilePicker(
            context,
            dataParameters,
            headers,
            apiUrl,
            uploadKey
        );
      }else {
        selectedImage = null;
      }
    }
  }
  return selectedImage;
}

///---------------------- Multiple Files Picker --------------------------------
Future<dynamic> multipleFilePicker(BuildContext context,
    Map<String, String> dataParameters,
    Map<String, String> headers,
    String apiUrl, String uploadKey, {
  FileType fileType,
  List<String> allowedExtensions
}) async {
  FilePickerResult result = await FilePicker.platform.pickFiles(
    allowMultiple: true,
    type: fileType ?? FileType.any,
    allowedExtensions: fileType !=null?allowedExtensions:null,
  );

  if(kIsWeb){
    // List<File> files = result?.files.map((path) => File(path.name)).toList();
    // return files;
    if(apiUrl != null && result != null) {
      dynamic response = await uploadMultipleFilesUsingAPIWeb(
          context,
          result?.files,
          {},
          {},
          apiUrl,
          uploadKey
      );
      return response;
    } else return null;
  }
  else {
    List<File> files = result?.paths.map((path) => File(path)).toList();
    // return files;
    dynamic response = await uploadMultipleFilesUsingAPI(
      context,
      files,
      {},
      {},
      apiUrl,
      uploadKey
    );
    return response;
  }
}


///-------------------- Request for Storage Permission -------------------------
Future<bool> requestStoragePermission(context) async {
  PermissionStatus requestStatus = await Permission.storage.request();
  if(requestStatus.isGranted || requestStatus.isLimited) {
    return true;
  } else {
    return false;
  }
}

///-------------------- Check Storage Permission -------------------------------
Future<bool> checkStoragePermission(context) async {
  PermissionStatus status = await Permission.storage.status;
  if(status.isGranted || status.isLimited) {
    return true;
  } else {
    return false;
  }
}

Future<dynamic> uploadMultipleFilesUsingAPI(BuildContext context,
    List<File> files,
    Map<String, String> dataParameters,
    Map<String, String> headers,
    String apiSourceUrl,
    String uploadKey) async {

  var request = http.MultipartRequest('POST', Uri.parse(apiSourceUrl));
  request.headers.addAll(headers);
  request.fields.addAll(dataParameters);

  await Future.forEach(files, (File file) async {
    var _uploadFile = await http.MultipartFile.fromPath(uploadKey??'files', file.path);
    request.files.add(_uploadFile);
  });


  var response = await request.send();
  var responseData = await response.stream.toBytes();
  var jsonResponse = String.fromCharCodes(responseData);
  // print("jsonResponse ==== $jsonResponse");
  Map<String, dynamic> jsonResponseData = json.decode(jsonResponse);
  return jsonResponseData;
}

Future<dynamic> uploadMultipleFilesUsingAPIWeb(BuildContext context,
    List<PlatformFile> files,
    Map<String, String> dataParameters,
    Map<String, String> headers,
    String apiSourceUrl,
    String uploadKey) async {

  var request = http.MultipartRequest('POST', Uri.parse(apiSourceUrl));
  request.headers.addAll(headers);
  request.fields.addAll(dataParameters);

  await Future.forEach(files, (PlatformFile file) async {
    Uint8List _fileData = file.bytes;
    String fileName = file.name;
    if(_fileData != null) {
      var _uploadFile = await http.MultipartFile.fromBytes(
          uploadKey ?? 'files',
          _fileData,
          filename: fileName
      );
      request.files.add(_uploadFile);
    }
    // var _uploadFile = await http.MultipartFile.fromPath(uploadKey??'files', file.path);
    // request.files.add(_uploadFile);
  });


  var response = await request.send();
  var responseData = await response.stream.toBytes();
  var jsonResponse = String.fromCharCodes(responseData);
  // print("jsonResponse ==== $jsonResponse");
  Map<String, dynamic> jsonResponseData = json.decode(jsonResponse);
  return jsonResponseData;
}