/*
Widget Name:
- Custom Paginated Data Table

Description:
- Custom Paginated Table is a simple navigation method that lets you split a huge amount of content within your tables into smaller parts. By default, pagination is initialized with Previous, page numbers and Next buttons.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-paginated-table.dart';

Usage:
- Defining the callback and Paginated Data Table objects

class TableRowdata{
   final sno;
  final requirements;
  Widget proof;
  TableRowdata({@required this.sno,@required this.requirements,@required this.proof});
}

List<TableRowdata> newDataList = [
  TableRowdata(
      sno: '1', requirements: 'GST Form', proof: Text('text1')),
  TableRowdata(
      sno: '2',
      requirements: 'TIN Details',
      proof: Text('text2')),
  TableRowdata(
      sno: '3', requirements: 'Signature', proof: Text('text3')),
  TableRowdata(
      sno: '4',
      requirements: 'Bank Statement',
      proof: Text('text4')),
];

class DTS extends DataTableSource {
  @override
  DataRow getRow(int index) {
    final Userr = newDataList[index];
    print(Userr);
    return DataRow(
        selected: true,
        cells: newDataList.length > 0
            ? [
                DataCell(Text((index + 1).toString())),
                DataCell(Text(Userr.requirements)),
                DataCell(Userr.proof),
              ]:[
          DataCell(Text(
            'No Records Found !',
            style: GoogleFonts.getFont('Roboto',color: Colors.black,fontSize: 25),
          )),
          DataCell(Text(''))
        ]);
  }

  @override
  
  bool get isRowCountApproximate => false;

  @override
  
  int get rowCount => newDataList.length;

  @override
  
  int get selectedRowCount => 0;
}
  final PaginatedDataTableData data = new PaginatedDataTableData(
      tableData: DTS(),
      headerText: null,
      sortAscending: null,
      sortColumnIndex: null,
      columnSpacing: 140,
      dataRowHeight: 50,
      rowsPerPage: 2,
      columns: <DataColumn>[
        DataColumn(
          label: Text('S.No',
              textAlign: TextAlign.center,
              style: new GoogleFonts.getFont('Roboto',fontSize: 18.0)),
        ),
        DataColumn(
          label: Text('Docs',
              textAlign: TextAlign.center,
              style: new GoogleFonts.getFont('Roboto',fontSize: 18.0)),
        ),
        DataColumn(
          label: Text('Status',
              textAlign: TextAlign.center,
              style: new GoogleFonts.getFont('Roboto',fontSize: 18.0)),
        ),
      ],
      theme: ThemeData(
        dividerColor: Colors.indigo,
        cardColor: Colors.white,
        applyElevationOverlayColor: true,
        iconTheme: IconThemeData(
            color: Colors.pink, opacity: 10),
  ));

- Widget call

      body: Container(
          child: CustompaginatedDataTable(
        data: data,
      )),

Author:
- Satyabrat Padhy
*/

import 'dart:async';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/consts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'dart:math' as math;
import 'package:flutter/rendering.dart';
import 'package:flutter/gestures.dart' show DragStartBehavior;

class CustompaginatedDataTable extends StatefulWidget {
  final PaginatedDataTableData data;
  CustompaginatedDataTable({@required this.data});
  @override
  CustompaginatedDataTableState createState() =>
      CustompaginatedDataTableState();
}

class CustompaginatedDataTableState extends State<CustompaginatedDataTable> {
  // ignore: close_sinks
  StreamController _streamController;
  Stream _stream;
  var dts;
  //TextEditingController _textController = TextEditingController();

  void initState() {
    super.initState();
    dts = widget.data.tableData;
    _streamController = StreamController();
    _stream = _streamController.stream;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            SizedBox(
              height: heightTwenty,
            ),
            Theme(
              data: widget.data.theme != null
                  ? widget.data.theme
                  : Theme.of(context).copyWith(
                      dividerColor: mediumGreyThemeData().hintColor,
                      cardColor: mediumGreyThemeData().accentColor,
                      applyElevationOverlayColor: true,
                      iconTheme: IconThemeData(
                          color: mediumGreyThemeData().primaryColor,
                          opacity: heightTen),
                    ),
              child: StreamBuilder(
                stream: _stream,
                builder: (BuildContext ctx, AsyncSnapshot snapshot) {
                  return CustomPaginatedDataTable(
                    header: Text(
                      widget.data.headerText != null
                          ? widget.data.headerText
                          : dialogHeader,
                      style: GoogleFonts.getFont('Roboto',color: Colors.black),
                    ),
                    sortAscending: widget.data.sortAscending != null
                        ? widget.data.sortAscending
                        : false,
                    sortColumnIndex: widget.data.sortColumnIndex != null
                        ? widget.data.sortColumnIndex
                        : null,
                    columns: widget.data.columns != null &&
                            widget.data.tableData.rowCount > 0
                        ? widget.data.columns
                        : <DataColumn>[
                            DataColumn(label: Text(txtColOne)),
                            DataColumn(label: Text(txtColTwo)),
                          ],
                    source: widget.data.tableData != null &&
                            widget.data.tableData.rowCount > 0
                        ? widget.data.tableData
                        : DefaultDTS(),
                    rowsPerPage: widget.data.rowsPerPage != null &&
                            widget.data.tableData != null &&
                            widget.data.tableData.rowCount > 0
                        ? widget.data.rowsPerPage
                        : intOne,
                    onRowsPerPageChanged: null,
                    actions:
                        widget.data.actions != null ? widget.data.actions : [],
                    columnSpacing: widget.data.columnSpacing != null
                        ? widget.data.columnSpacing
                        : heightTwenty,
                    dataRowHeight: widget.data.dataRowHeight != null
                        ? widget.data.dataRowHeight
                        : heightHundred + heightTen,
                    availableRowsPerPage:
                        widget.data.availableRowsPerPage != null
                            ? widget.data.availableRowsPerPage
                            : [intOne],
                    horizontalMargin: widget.data.horizontalMargin != null
                        ? widget.data.horizontalMargin
                        : heightTwenty,
                  );
                },
              ),
            ),
          ],
        ),
      ),
    );
  }
}

class DefaultDTS extends DataTableSource {
  @override
  DataRow getRow(int index) {
    return DataRow(selected: true, cells: [
      DataCell(Text(
        noDataMsg,
        style: GoogleFonts.getFont('Roboto',color: Colors.black, fontSize: 25),
      )),
      DataCell(Text(''))
    ]);
  }

  @override
  bool get isRowCountApproximate => false;

  @override
  int get rowCount => intOne;

  @override
  int get selectedRowCount => zero;
}

////Source Code For Custom Paginated Table
class CustomPaginatedDataTable extends StatefulWidget {
  CustomPaginatedDataTable({
    Key key,
    @required this.header,
    this.actions,
    @required this.columns,
    this.sortColumnIndex,
    this.sortAscending = true,
    this.onSelectAll,
    this.dataRowHeight = kMinInteractiveDimension,
    this.headingRowHeight = heightFifty + heightFive,
    this.horizontalMargin = heightTwentyFive,
    this.columnSpacing = heightFifty + heightFive,
    this.initialFirstRowIndex = zero,
    this.onPageChanged,
    this.rowsPerPage = defaultRowsPerPage,
    this.availableRowsPerPage = const <int>[
      defaultRowsPerPage,
      defaultRowsPerPage * intTwo,
      defaultRowsPerPage * intFive,
      defaultRowsPerPage * intFive * intTwo
    ],
    this.onRowsPerPageChanged,
    this.dragStartBehavior = DragStartBehavior.start,
    @required this.source,
  })  : assert(header != null),
        assert(columns != null),
        assert(dragStartBehavior != null),
        assert(columns.isNotEmpty),
        assert(sortColumnIndex == null ||
            (sortColumnIndex >= 0 && sortColumnIndex < columns.length)),
        assert(sortAscending != null),
        assert(dataRowHeight != null),
        assert(headingRowHeight != null),
        assert(horizontalMargin != null),
        assert(columnSpacing != null),
        assert(rowsPerPage != null),
        assert(rowsPerPage > 0),
        assert(() {
          if (onRowsPerPageChanged != null)
            assert(availableRowsPerPage != null &&
                availableRowsPerPage.contains(rowsPerPage));
          return true;
        }()),
        assert(source != null),
        super(key: key);
  final Widget header;
  final List<Widget> actions;
  final List<DataColumn> columns;
  final int sortColumnIndex;
  final bool sortAscending;
  final ValueSetter<bool> onSelectAll;
  final double dataRowHeight;
  final double headingRowHeight;
  final double horizontalMargin;
  final double columnSpacing;
  final int initialFirstRowIndex;
  final ValueChanged<int> onPageChanged;
  final int rowsPerPage;
  static const int defaultRowsPerPage = intFive * intTwo;
  final List<int> availableRowsPerPage;
  final ValueChanged<int> onRowsPerPageChanged;
  final DataTableSource source;
  final DragStartBehavior dragStartBehavior;

  @override
  CustomPaginatedDataTableState createState() =>
      CustomPaginatedDataTableState();
}

class CustomPaginatedDataTableState extends State<CustomPaginatedDataTable> {
  int _firstRowIndex;
  int _rowCount;
  bool _rowCountApproximate;
  int _selectedRowCount;
  final Map<int, DataRow> _rows = <int, DataRow>{};

  @override
  void initState() {
    super.initState();
    _firstRowIndex = PageStorage.of(context)?.readState(context) ??
        widget.initialFirstRowIndex ??
        0;
    widget.source.addListener(_handleDataSourceChanged);
    _handleDataSourceChanged();
  }

  @override
  void didUpdateWidget(CustomPaginatedDataTable oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.source != widget.source) {
      oldWidget.source.removeListener(_handleDataSourceChanged);
      widget.source.addListener(_handleDataSourceChanged);
      _handleDataSourceChanged();
    }
  }

  @override
  void dispose() {
    widget.source.removeListener(_handleDataSourceChanged);
    super.dispose();
  }

  void _handleDataSourceChanged() {
    setState(() {
      _rowCount = widget.source.rowCount;
      _rowCountApproximate = widget.source.isRowCountApproximate;
      _selectedRowCount = widget.source.selectedRowCount;
      _rows.clear();
    });
  }

  /// Ensures that the given row is visible.
  void pageTo(int rowIndex) {
    final int oldFirstRowIndex = _firstRowIndex;
    setState(() {
      final int rowsPerPage = widget.rowsPerPage;
      _firstRowIndex = (rowIndex ~/ rowsPerPage) * rowsPerPage;
    });
    if ((widget.onPageChanged != null) && (oldFirstRowIndex != _firstRowIndex))
      widget.onPageChanged(_firstRowIndex);
  }

  DataRow _getBlankRowFor(int index) {
    return DataRow.byIndex(
      index: index,
      cells: widget.columns
          .map<DataCell>((DataColumn column) => DataCell.empty)
          .toList(),
    );
  }

  DataRow _getProgressIndicatorRowFor(int index) {
    bool haveProgressIndicator = false;
    final List<DataCell> cells =
        widget.columns.map<DataCell>((DataColumn column) {
      if (!column.numeric) {
        haveProgressIndicator = true;
        return const DataCell(CircularProgressIndicator());
      }
      return DataCell.empty;
    }).toList();
    if (!haveProgressIndicator) {
      haveProgressIndicator = true;
      cells[0] = const DataCell(CircularProgressIndicator());
    }
    return DataRow.byIndex(
      index: index,
      cells: cells,
    );
  }

  List<DataRow> _getRows(int firstRowIndex, int rowsPerPage) {
    final List<DataRow> result = <DataRow>[];
    final int nextPageFirstRowIndex = firstRowIndex + rowsPerPage;
    bool haveProgressIndicator = false;
    for (int index = firstRowIndex; index < nextPageFirstRowIndex; index += 1) {
      DataRow row;
      if (index < _rowCount || _rowCountApproximate) {
        row = _rows.putIfAbsent(index, () => widget.source.getRow(index));
        if (row == null && !haveProgressIndicator) {
          row ??= _getProgressIndicatorRowFor(index);
          haveProgressIndicator = true;
        }
      }
      row ??= _getBlankRowFor(index);
      result.add(row);
    }
    return result;
  }

  void _handlePrevious() {
    pageTo(math.max(_firstRowIndex - widget.rowsPerPage, 0));
  }

  void _handleNext() {
    pageTo(_firstRowIndex + widget.rowsPerPage);
  }

  final GlobalKey _tableKey = GlobalKey();

  @override
  Widget build(BuildContext context) {
    assert(debugCheckHasMaterialLocalizations(context));
    final ThemeData themeData = Theme.of(context);
    final MaterialLocalizations localizations =
        MaterialLocalizations.of(context);
    // HEADER
    final List<Widget> headerWidgets = <Widget>[];
    double startPadding = heightTwentyFive;
    if (_selectedRowCount == 0) {
      headerWidgets.add(Expanded(child: widget.header));
      if (widget.header is ButtonBar) {
        startPadding = heightTen + heightTwo;
      }
    } else {
      headerWidgets.add(Expanded(
        child: Text(localizations.selectedRowCountTitle(_selectedRowCount)),
      ));
    }
    if (widget.actions != null) {
      headerWidgets.addAll(widget.actions.map<Widget>((Widget action) {
        return Padding(
          // 8.0 is the default padding of an icon button
          padding: const EdgeInsetsDirectional.only(start: 24.0 - 8.0 * 2.0),
          child: action,
        );
      }).toList());
    }

    // FOOTER
    final TextStyle footerTextStyle = themeData.textTheme.caption;
    final List<Widget> footerWidgets = <Widget>[];
    if (widget.onRowsPerPageChanged != null) {
      final List<Widget> availableRowsPerPage = widget.availableRowsPerPage
          .where(
              (int value) => value <= _rowCount || value == widget.rowsPerPage)
          .map<DropdownMenuItem<int>>((int value) {
        return DropdownMenuItem<int>(
          value: value,
          child: Text('$value'),
        );
      }).toList();
      footerWidgets.addAll(<Widget>[
        Container(
            width:
                14.0), // to match trailing padding in case we overflow and end up scrolling
        Text(localizations.rowsPerPageTitle),
        ConstrainedBox(
          constraints: const BoxConstraints(
              minWidth: 64.0), // 40.0 for the text, 24.0 for the icon
          child: Align(
            alignment: AlignmentDirectional.centerEnd,
            child: DropdownButtonHideUnderline(
              child: DropdownButton<int>(
                items: availableRowsPerPage,
                value: widget.rowsPerPage,
                onChanged: widget.onRowsPerPageChanged,
                style: footerTextStyle,
                iconSize: 24.0,
              ),
            ),
          ),
        ),
      ]);
    }
    footerWidgets.addAll(<Widget>[
      Container(width: 32.0),
      IconButton(
        icon: const Icon(Icons.chevron_left,color:Colors.black),
        padding: EdgeInsets.zero,
        tooltip: localizations.previousPageTooltip,
        onPressed: _firstRowIndex <= 0 ? null : _handlePrevious,
      ),
      Container(width: 32.0),
      Text(
        localizations.pageRowsInfoTitle(
          _firstRowIndex + 1,
          _firstRowIndex + widget.rowsPerPage,
          _rowCount,
          _rowCountApproximate,
        ),
      ),
      Container(width: 24.0),
      IconButton(
        icon: const Icon(Icons.chevron_right,color:Colors.black),
        padding: EdgeInsets.zero,
        tooltip: localizations.nextPageTooltip,
        onPressed: (!_rowCountApproximate &&
                (_firstRowIndex + widget.rowsPerPage >= _rowCount))
            ? null
            : _handleNext,
      ),
      Container(width: 14.0),
    ]);

    // CARD
    return Card(
      semanticContainer: false,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: <Widget>[
          Semantics(
            container: true,
            child: DefaultTextStyle(
              style: _selectedRowCount > 0
                  ? themeData.textTheme.subtitle1
                      .copyWith(color: themeData.accentColor)
                  : themeData.textTheme.headline6
                      .copyWith(fontWeight: FontWeight.w400),
              child: IconTheme.merge(
                data: const IconThemeData(opacity: 0.54),
                child: Ink(
                  height: 64.0,
                  color: _selectedRowCount > 0
                      ? themeData.secondaryHeaderColor
                      : null,
                  child: Padding(
                    padding: EdgeInsetsDirectional.only(
                        start: startPadding, end: 14.0),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.end,
                      children: headerWidgets,
                    ),
                  ),
                ),
              ),
            ),
          ),
          SingleChildScrollView(
            scrollDirection: Axis.horizontal,
            dragStartBehavior: widget.dragStartBehavior,
            child: DataTable(
              key: _tableKey,
              columns: widget.columns,
              sortColumnIndex: widget.sortColumnIndex,
              sortAscending: widget.sortAscending,
              onSelectAll: widget.onSelectAll,
              dataRowHeight: widget.dataRowHeight,
              headingRowHeight: widget.headingRowHeight,
              horizontalMargin: widget.horizontalMargin,
              columnSpacing: widget.columnSpacing,
              rows: _getRows(_firstRowIndex, widget.rowsPerPage),
            ),
          ),
          DefaultTextStyle(
            style: footerTextStyle,
            child: IconTheme.merge(
              data: const IconThemeData(opacity: 0.54),
              child: Container(
                height: heightFifty + heightFive,
                child: SingleChildScrollView(
//                  dragStartBehavior: widget.dragStartBehavior,
//                  scrollDirection: Axis.horizontal,
//                  reverse: true,
                  child: Container(
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: footerWidgets,
                    ),
                  ),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
