/*
Implementation:

Imports:
import 'custom-pieChart.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.


    Object:
    List<ServicesData> pieChartData = [
      new ServicesData('Active', 30, Colors.orange),
      new ServicesData('Pending', 10, Colors.black),
      new ServicesData('Completed', 40, Colors.red),
      new ServicesData('Requested', 20, Colors.grey),
    ];

    List<charts.Series<ServicesData, String>> pieSeries = [
      new charts.Series<ServicesData, String>(
        id: 'Sales',
        domainFn: (ServicesData sales, _) => sales.serviceType,
        measureFn: (ServicesData sales, _) => sales.serviceNumber,
        colorFn: (ServicesData sales, _) =>
            charts.ColorUtil.fromDartColor(sales.mColor),
        labelAccessorFn: (ServicesData row, _) => '${row.serviceNumber}',
        data: pieChartData,
      )
    ];
    ChartsPie objPieOne = new ChartsPie(pieSeries, 50);

    Object Call:
        body: objPieOne,
*/

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'package:rapid_widgets_library/consts.dart' as cons;

class ChartsPie extends StatefulWidget {
  final List<charts.Series<dynamic, dynamic>> chartData;
  final int arcValue;
  final int labelFontSize;
  ChartsPie(this.chartData, this.arcValue, this.labelFontSize);

  @override
  State<StatefulWidget> createState() {
    return _Chartspie(chartData, arcValue, labelFontSize);
  }
}

class _Chartspie extends State<ChartsPie> {
  List<charts.Series<dynamic, dynamic>> chartData;
  int arcValue;
  int labelFontSize;
  _Chartspie(this.chartData, this.arcValue, this.labelFontSize);

  @override
  Widget build(BuildContext context) {
    return _createPieChart(chartData, arcValue, labelFontSize);
  }

  Widget _createPieChart(List<charts.Series<dynamic, dynamic>> objSeries,
      int arcValue, int labelFontSize) {
    charts.PieChart mPieChart;

    mPieChart = new charts.PieChart(
      objSeries,
      animate: true,
      animationDuration: Duration(seconds: cons.pieAnimationTime),
      defaultRenderer: new charts.ArcRendererConfig(
          arcWidth: arcValue,
          arcRendererDecorators: [
            new charts.ArcLabelDecorator(
              outsideLabelStyleSpec:
                  new charts.TextStyleSpec(fontSize: labelFontSize),
              labelPosition: charts.ArcLabelPosition.auto,
            )
          ]),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: cons.pieMaxRows,
        )
      ],
    );
    return mPieChart;
  }
}
